# Changelog

## 0.1.0

 - Initial release

## 1.0.0

 - Unit tests
 - Add Oritentation on manifest.json
 - Add tox
 - Add Coverage
 
 
 ## 1.0.1
 
 - Add django 2 requirement
 - Use templateviews instead of own implementations
 - Add content_types
 - Update `README.md`
 - Add `PWA_APP_FETCH_URL` 
 - Add default_config in `__init__.py`
 - Add basic serviceworker
 - Add default offline page and default icons
 - Updated the unit tests
 